//==========================================================================================================================
// Some basic USART routines for ATmega644
//==========================================================================================================================
#include <avr/io.h>

#include "serial.h"

// ------ clear rx fifo ------
void inline rx_flush(void)
{
	UDR0;
	UDR0;
	UDR0;
}

// ------ try get byte ------
uint8_t rx_byte_try(uint8_t *byte)
{
	if(bit_is_set(UCSR0A,RXC0))
	{
		*byte = UDR0;
		return(1);
	}
	else
		return(0);
}

// ------ get byte ------
uint8_t rx_byte(void)
{
	loop_until_bit_is_set(UCSR0A,RXC0);
	return(UDR0);
}

// ------ get word ------
uint16_t rx_word(void)
{
	union{
		uint8_t byte[2];
		uint32_t wrd;
	}wrd;
	wrd.byte[0]=rx_byte();
	wrd.byte[1]=rx_byte();
	return(wrd.wrd);
}

// ------ get dword ------
uint32_t rx_dword(void)
{
	union{
		uint8_t byte[4];
		uint32_t dwrd;
	}dwrd;
	dwrd.byte[0]=rx_byte();
	dwrd.byte[1]=rx_byte();
	dwrd.byte[2]=rx_byte();
	dwrd.byte[3]=rx_byte();
	return(dwrd.dwrd);
}





// ------ send byte ------
void tx_byte(uint8_t byte)
{
	loop_until_bit_is_set(UCSR0A,UDRE0);
	loop_until_bit_is_clear(PIND,PD2);
	UDR0=byte;
}

// ------ send word ------
void tx_word(uint16_t wrd)
{
	union{
		uint8_t byte[2];
		uint16_t wrd;
	}uni;
	uni.wrd=wrd;
	
	tx_byte(uni.byte[0]);
	tx_byte(uni.byte[1]);
}

// ------ send dword ------
void tx_dword(uint32_t dwrd)
{
	union{
		uint8_t byte[4];
		uint32_t dwrd;
	}uni;
	uni.dwrd=dwrd;

	tx_byte(uni.byte[0]);
	tx_byte(uni.byte[1]);
	tx_byte(uni.byte[2]);
	tx_byte(uni.byte[3]);
}



